# Semantic Kernel Integration with MCP Gateway

[Semantic Kernel](https://aka.ms/semantic-kernel) is a Microsoft OSS framework for building AI-first apps.

---

## 🔧 MCP Integration

Support for external tools via REST allows you to call MCP tools from SK plugins using `HttpFunction`.

Define a plugin that points to MCP Gateway's `/tools/invoke` and pass arguments as JSON.

---

## 🔗 Resources

- [Semantic Kernel GitHub](https://github.com/microsoft/semantic-kernel)
- [Using REST APIs in SK](https://learn.microsoft.com/en-us/semantic-kernel/)
